==> v8.3.zip: ru_twords_ru_tw/bible/other/warrior.md <==
# воин, солдат

## Определение:

Воин или солдат — это человек, воюющий на поле битвы или служащий в армии. Эти слова могут также употребляться и в переносном значении.

* Слово “воин” имеет широкое значение. Это и воинственный человек, и служащий в армии человек, а также человек, обладающий такими чертами характера, как мужество, отвага, бесстрашие, доблесть.
* В Библии о Яхве говорится, что Он — Великий Воин.
* Слово “солдат” более конкретно. Это человек, который служит в армии, выполняет какие-либо воинские функции и участвует в боевых действиях.
* В обязанности римских солдат в Иерусалиме также входили поддержание порядка и осуществление казней над преступниками. Они охраняли Иисуса Христа перед тем, как Он был распят, а также после того, как Он был положен в гробнице.
* Обратите внимание, насколько эти слова различаются в целевом языке, и выберете то, которое наилучшим образом соответствует контексту. При переводе следует понять, различаются ли эти слова по смыслу в целевом языке (если таковые имеются).

(См. также: [мужество](../other/courage.md), [распять](../kt/crucify.md), [Рим](../names/rome.md), [гробница](../other/tomb.md))

## Ссылки на библейский текст:

* [1 Пар. 21:4-5](rc://*/tn/help/1ch/21/04)
* [Деян. 21:32-33](rc://*/tn/help/act/21/32)
* [Лк. 3:14](rc://*/tn/help/luk/03/14)
* [Лк. 23:11-12](rc://*/tn/help/luk/23/11)
* [Мф. 8:8-10](rc://*/tn/help/mat/08/08)

## Данные о слове:

* Номера Стронга: H352, H510, H1368, H1416, H1995, H2389, H2428, H2502, H3715, H4421, H5431, H5971, H6518, H6635, H7273, H7916, G4686, G4753, G4754, G4757, G4758, G4961

==> v9.2.zip: ru_twords_ru_tw/bible/other/warrior.md <==
# воин, солдат

## Определение:

Воин или солдат — это человек, воюющий на поле битвы или служащий в армии. Эти слова могут также употребляться и в переносном значении.
* Слово “воин” имеет широкое значение. Это и воинственный человек, и служащий в армии человек, а также человек, обладающий такими чертами характера, как мужество, отвага, бесстрашие, доблесть.
* В Библии о Яхве говорится, что Он — Великий Воин.
* Слово “солдат” более конкретно. Это человек, который служит в армии, выполняет какие-либо воинские функции и участвует в боевых действиях.
* В обязанности римских солдат в Иерусалиме также входили поддержание порядка и осуществление казней над преступниками. Они охраняли Иисуса Христа перед тем, как Он был распят, а также после того, как Он был положен в гробнице.
* Обратите внимание, насколько эти слова различаются в целевом языке, и выберете то, которое наилучшим образом соответствует контексту. При переводе следует понять, различаются ли эти слова по смыслу в целевом языке (если таковые имеются).

(См. также: [мужество](../other/courage.md), [распять](../kt/crucify.md), [Рим](../names/rome.md), [гробница](../other/tomb.md))

## Ссылки на библейский текст:

* [1 Пар. 21:4-5](rc://ru/tn/help/1ch/21/04)
* [Деян. 21:32-33](rc://ru/tn/help/act/21/32)
* [Лк. 3:14](rc://ru/tn/help/luk/03/14)
* [Лк. 23:11-12](rc://ru/tn/help/luk/23/11)
* [Мф. 8:8-10](rc://ru/tn/help/mat/08/08)

## Данные о слове:

* Номера Стронга: H352, H510, H1368, H1416, H1995, H2389, H2428, H2502, H3715, H4421, H5431, H5971, H6518, H6635, H7273, H7916, G4686, G4753, G4754, G4757, G4758, G4961
